@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ SelectMatchTypeComboBox::SelectMatchTypeComboBox(SieveEditorGraphicalModeWidget
     connect(this, &SelectMatchTypeComboBox::activated, this, &SelectMatchTypeComboBox::slotValueChanged);
 }
 
-SelectMatchTypeComboBox::~SelectMatchTypeComboBox()
-{
-}
+SelectMatchTypeComboBox::~SelectMatchTypeComboBox() = default;
 
 void SelectMatchTypeComboBox::slotValueChanged(int val)
 {
