@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionfileinto.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "editor/sieveeditorutil.h"
 #include "widgets/moveimapfolderwidget.h"
-#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include <KLocalizedString>
 
+#include "libksieve_debug.h"
 #include <QCheckBox>
 #include <QHBoxLayout>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
-//Add support for adding flags
+// Add support for adding flags
 using namespace KSieveUi;
 SieveActionFileInto::SieveActionFileInto(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveAction(sieveGraphicalModeWidget, QStringLiteral("fileinto"), i18n("File Into"), parent)
@@ -59,12 +46,16 @@ QString SieveActionFileInto::code(QWidget *w) const
 void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("copy")) {
                 if (mHasCopySupport) {
-                    QCheckBox *copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
+                    auto copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
                     copy->setChecked(true);
                 } else {
                     error += i18n("Action \"fileinto\" has \"copy\" argument but current server does not support it") + QLatin1Char('\n');
@@ -72,7 +63,7 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
                 }
             } else if (tagValue == QLatin1String("create")) {
                 if (mHasMailBoxSupport) {
-                    QCheckBox *create = w->findChild<QCheckBox *>(QStringLiteral("create"));
+                    auto create = w->findChild<QCheckBox *>(QStringLiteral("create"));
                     create->setChecked(true);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("create"), error);
@@ -84,14 +75,14 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
         } else if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            KSieveUi::AbstractMoveImapFolderWidget *edit = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("fileintolineedit"));
+            auto edit = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("fileintolineedit"));
             edit->setText(AutoCreateScriptUtil::protectSlash(tagValue));
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionFileInto::setParamWidgetValue unknown tagName " << tagName;
@@ -101,18 +92,18 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
 
 QWidget *SieveActionFileInto::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout(w);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout(w);
+    lay->setContentsMargins({});
 
     if (mHasCopySupport) {
-        QCheckBox *copy = new QCheckBox(i18n("Keep a copy"));
+        auto copy = new QCheckBox(i18n("Keep a copy"));
         copy->setObjectName(QStringLiteral("copy"));
         lay->addWidget(copy);
         connect(copy, &QCheckBox::clicked, this, &SieveActionFileInto::valueChanged);
     }
     if (mHasMailBoxSupport) {
-        QCheckBox *create = new QCheckBox(i18n("Create folder"));
+        auto create = new QCheckBox(i18n("Create folder"));
         create->setObjectName(QStringLiteral("create"));
         connect(create, &QCheckBox::clicked, this, &SieveActionFileInto::valueChanged);
         lay->addWidget(create);
@@ -159,12 +150,14 @@ QString SieveActionFileInto::help() const
 {
     QString helpStr = i18n("The \"fileinto\" action delivers the message into the specified mailbox.");
     if (mHasMailBoxSupport) {
-        helpStr += QLatin1Char('\n') + i18n(
-            "If the optional \":create\" argument is specified, it instructs the Sieve interpreter to create the specified mailbox, if needed, before attempting to deliver the message into the specified mailbox.");
+        helpStr += QLatin1Char('\n')
+            + i18n("If the optional \":create\" argument is specified, it instructs the Sieve interpreter to create the specified mailbox, if needed, before "
+                   "attempting to deliver the message into the specified mailbox.");
     }
     if (mHasCopySupport) {
-        helpStr += QLatin1Char('\n') + i18n(
-            "If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it merely files or redirects a copy in addition to whatever else is happening to the message.");
+        helpStr += QLatin1Char('\n')
+            + i18n("If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it merely files or "
+                   "redirects a copy in addition to whatever else is happening to the message.");
     }
     return helpStr;
 }
