@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ SelectVariableModifierComboBox::SelectVariableModifierComboBox(QWidget *parent)
     connect(this, &SelectVariableModifierComboBox::activated, this, &SelectVariableModifierComboBox::valueChanged);
 }
 
-SelectVariableModifierComboBox::~SelectVariableModifierComboBox()
-{
-}
+SelectVariableModifierComboBox::~SelectVariableModifierComboBox() = default;
 
 void SelectVariableModifierComboBox::initialize()
 {
