@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionaddress.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include "widgets/selectaddresspartcombobox.h"
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
-#include "widgets/selectheadertypecombobox.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/selectaddresspartcombobox.h"
+#include "widgets/selectheadertypecombobox.h"
 
 #include <KLocalizedString>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
 
 using namespace KSieveUi;
@@ -39,30 +26,30 @@ SieveConditionAddress::SieveConditionAddress(SieveEditorGraphicalModeWidget *sie
 
 QWidget *SieveConditionAddress::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectAddressPartComboBox *selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
+    auto selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
     connect(selectAddressPart, &SelectAddressPartComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectAddressPart->setObjectName(QStringLiteral("addresspartcombobox"));
     lay->addWidget(selectAddressPart);
 
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto grid = new QGridLayout;
+    grid->setContentsMargins({});
     lay->addLayout(grid);
-    SelectMatchTypeComboBox *selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     connect(selectMatchCombobox, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectMatchCombobox->setObjectName(QStringLiteral("matchtypecombobox"));
     grid->addWidget(selectMatchCombobox, 0, 0);
 
-    SelectHeaderTypeComboBox *selectHeaderType = new SelectHeaderTypeComboBox(true);
+    auto selectHeaderType = new SelectHeaderTypeComboBox(true);
     connect(selectHeaderType, &SelectHeaderTypeComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectHeaderType->setObjectName(QStringLiteral("headertypecombobox"));
     grid->addWidget(selectHeaderType, 0, 1);
 
-    QLabel *lab = new QLabel(i18n("address:"));
+    auto lab = new QLabel(i18n("address:"));
     grid->addWidget(lab, 1, 0);
 
     AbstractRegexpEditorLineEdit *edit = AutoCreateScriptUtil::createRegexpEditorLineEdit();
@@ -89,8 +76,9 @@ QString SieveConditionAddress::code(QWidget *w) const
 
     const AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
     const QString addressStr = AutoCreateScriptUtil::createAddressList(edit->code().trimmed(), false);
-    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
-           + AutoCreateScriptUtil::generateConditionComment(comment());
+    return AutoCreateScriptUtil::negativeString(isNegative)
+        + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
+        + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QStringList SieveConditionAddress::needRequires(QWidget *w) const
@@ -104,47 +92,52 @@ QStringList SieveConditionAddress::needRequires(QWidget *w) const
 QString SieveConditionAddress::help() const
 {
     return i18n(
-        "The \"address\" test matches Internet addresses in structured headers that contain addresses.  It returns true if any header contains any key in the specified part of the address, as modified by the comparator and the match keyword.");
+        "The \"address\" test matches Internet addresses in structured headers that contain addresses.  It returns true if any header contains any key in the "
+        "specified part of the address, as modified by the comparator and the match keyword.");
 }
 
-bool SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
+void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     int index = 0;
     int indexStr = 0;
     QStringList lstTagValue;
     QString commentStr;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
             lstTagValue << element.readElementText();
             ++index;
         } else if (tagName == QLatin1String("str")) {
             if (indexStr == 0) {
-                SelectHeaderTypeComboBox *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
                 selectHeaderType->setCode(element.readElementText());
             } else if (indexStr == 1) {
-                AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
                 edit->setCode(AutoCreateScriptUtil::quoteStr(element.readElementText()));
             } else {
-                tooManyArgument(tagName, indexStr, 2, error);
+                tooManyArguments(tagName, indexStr, 2, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionAddress::setParamWidgetValue too many argument :" << index;
             }
             ++indexStr;
         } else if (tagName == QLatin1String("list")) {
             if (indexStr == 0) {
-                SelectHeaderTypeComboBox *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
                 selectHeaderType->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else if (indexStr == 1) {
-                AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
                 edit->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else {
-                tooManyArgument(tagName, indexStr, 2, error);
+                tooManyArguments(tagName, indexStr, 2, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionAddress::setParamWidgetValue too many argument :" << index;
             }
             ++indexStr;
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
@@ -157,30 +150,28 @@ bool SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidg
     }
     if (lstTagValue.count() == 1) {
         QString specificError;
-        SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+        auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
         selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(0), notCondition), name(), specificError);
-        if (!specificError.isEmpty()) { //Test if default match type == is
-            SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+        if (!specificError.isEmpty()) { // Test if default match type == is
+            auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
             selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(0)), name(), error);
         }
     } else if (lstTagValue.count() == 2) {
         QString errorStr;
-        SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+        auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
         selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(0)), name(), errorStr);
         if (errorStr.isEmpty()) {
-            SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+            auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(1), notCondition), name(), error);
-        } else { //Problem with order
-            SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+        } else { // Problem with order
+            auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(0), notCondition), name(), error);
             selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(1)), name(), error);
         }
     } else if (lstTagValue.count() > 2) {
-        tooManyArgument(QStringLiteral("tag"), lstTagValue.count(), 2, error);
+        tooManyArguments(QStringLiteral("tag"), lstTagValue.count(), 2, error);
         qCDebug(LIBKSIEVE_LOG) << "SieveConditionAddress::setParamWidgetValue too many argument :" << lstTagValue.count();
     }
-
-    return true;
 }
 
 QUrl SieveConditionAddress::href() const
