@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ RegexpEditorLineEdit::RegexpEditorLineEdit(QWidget *parent)
     mainLayout->addWidget(mLineEdit);
 }
 
-RegexpEditorLineEdit::~RegexpEditorLineEdit()
-{
-}
+RegexpEditorLineEdit::~RegexpEditorLineEdit() = default;
 
 void RegexpEditorLineEdit::switchToRegexpEditorLineEdit(bool regexpEditor)
 {
