@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,16 +13,20 @@
 #include <QPushButton>
 
 #include <KConfigGroup>
+#include <KLazyLocalizedString>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
-
+#include <QWindow>
 using namespace KSieveUi;
-
-static const char selectMultipleHeaders[] = I18N_NOOP("Select multiple headers...");
-
+namespace
+{
+static const char mySelectFlagsListDialogGroupName[] = "SelectHeadersDialog";
+}
+const KLazyLocalizedString selectMultipleHeaders = kli18n("Select multiple headers...");
 SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
     : QDialog(parent)
     , mListWidget(new SelectHeadersWidget(this))
@@ -84,17 +88,17 @@ SelectHeadersDialog::~SelectHeadersDialog()
 
 void SelectHeadersDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectHeadersDialog");
-    const QSize size = group.readEntry("Size", QSize(400, 300));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(400, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectFlagsListDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SelectHeadersDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectHeadersDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectFlagsListDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
@@ -127,9 +131,7 @@ SelectHeadersWidget::SelectHeadersWidget(QWidget *parent)
 {
 }
 
-SelectHeadersWidget::~SelectHeadersWidget()
-{
-}
+SelectHeadersWidget::~SelectHeadersWidget() = default;
 
 void SelectHeadersWidget::addNewHeader(const QString &header)
 {
@@ -204,9 +206,7 @@ SelectHeaderTypeComboBox::SelectHeaderTypeComboBox(bool onlyEnvelopType, QWidget
     connect(this, &SelectHeaderTypeComboBox::activated, this, &SelectHeaderTypeComboBox::valueChanged);
 }
 
-SelectHeaderTypeComboBox::~SelectHeaderTypeComboBox()
-{
-}
+SelectHeaderTypeComboBox::~SelectHeaderTypeComboBox() = default;
 
 void SelectHeaderTypeComboBox::changeReadOnlyStatus()
 {
@@ -215,10 +215,15 @@ void SelectHeaderTypeComboBox::changeReadOnlyStatus()
     lineEdit()->setClearButtonEnabled(!readOnly);
 }
 
+const QString SelectHeaderTypeComboBox::getSelectMultipleHeadersTranslated() const
+{
+    return selectMultipleHeaders.toString();
+}
+
 void SelectHeaderTypeComboBox::slotSelectItem(const QString &str)
 {
     changeReadOnlyStatus();
-    if (str == i18n(selectMultipleHeaders)) {
+    if (str == getSelectMultipleHeadersTranslated()) {
         QPointer<SelectHeadersDialog> dlg = new SelectHeadersDialog(this);
         dlg->setListHeaders(mHeaderMap, AutoCreateScriptUtil::createListFromString(mCode));
         if (dlg->exec()) {
@@ -261,7 +266,7 @@ void SelectHeaderTypeComboBox::initialize(bool onlyEnvelopType)
         i.next();
         addItem(i.value(), i.key());
     }
-    addItem(i18n(selectMultipleHeaders));
+    addItem(getSelectMultipleHeadersTranslated());
 }
 
 QString SelectHeaderTypeComboBox::code() const
@@ -269,7 +274,7 @@ QString SelectHeaderTypeComboBox::code() const
     QString str = (currentIndex() > -1) ? itemData(currentIndex()).toString() : QString();
     if (str.isEmpty()) {
         str = currentText();
-        if (str == i18n(selectMultipleHeaders)) {
+        if (str == getSelectMultipleHeadersTranslated()) {
             str = QString(); // return QString();
         }
     }
