@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ SelectRelationalMatchType::SelectRelationalMatchType(QWidget *parent)
     initialize();
 }
 
-SelectRelationalMatchType::~SelectRelationalMatchType()
-{
-}
+SelectRelationalMatchType::~SelectRelationalMatchType() = default;
 
 void SelectRelationalMatchType::setCode(const QString &type, const QString &comparatorStr, const QString &name, QString &error)
 {
