@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -29,9 +29,7 @@ SelectSizeWidget::SelectSizeWidget(QWidget *parent)
     hbox->addWidget(mSelectSizeType);
 }
 
-SelectSizeWidget::~SelectSizeWidget()
-{
-}
+SelectSizeWidget::~SelectSizeWidget() = default;
 
 QString SelectSizeWidget::code() const
 {
