@@ -1,24 +1,10 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVECONDITIONWIDGETLISTER_H
-#define SIEVECONDITIONWIDGETLISTER_H
+#pragma once
 
 #include <Libkdepim/KWidgetLister>
 #include <QVector>
@@ -28,7 +14,8 @@ class QXmlStreamReader;
 class QToolButton;
 class QComboBox;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveCondition;
 class SieveHelpButton;
 class SieveEditorGraphicalModeWidget;
@@ -37,7 +24,7 @@ class SieveConditionWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveConditionWidget(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent);
-    ~SieveConditionWidget();
+    ~SieveConditionWidget() override;
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
     void generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop);
@@ -64,7 +51,7 @@ private:
     QGridLayout *mLayout = nullptr;
     SieveHelpButton *mHelpButton = nullptr;
     QToolButton *mCommentButton = nullptr;
-    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget = nullptr;
+    SieveEditorGraphicalModeWidget *const mSieveGraphicalModeWidget;
 };
 
 class SieveConditionWidgetLister : public KPIM::KWidgetLister
@@ -72,7 +59,7 @@ class SieveConditionWidgetLister : public KPIM::KWidgetLister
     Q_OBJECT
 public:
     explicit SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
-    ~SieveConditionWidgetLister();
+    ~SieveConditionWidgetLister() override;
 
     void generatedScript(QString &script, int &numberOfCondition, QStringList &requireModules, bool inForEveryPartLoop);
     int conditionNumber() const;
@@ -96,5 +83,3 @@ private:
     SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget = nullptr;
 };
 }
-
-#endif // SIEVECONDITIONWIDGETLISTER_H
