@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -106,8 +106,7 @@ private Q_SLOTS:
     void slotHelp();
 
 private:
-    SieveGlobalVariableLister *mIncludeLister = nullptr;
+    SieveGlobalVariableLister *mGlobalVariableLister = nullptr;
     SieveHelpButton *mHelpButton = nullptr;
 };
 }
-
