@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ SieveWidgetPageAbstract::SieveWidgetPageAbstract(QWidget *parent)
 {
 }
 
-SieveWidgetPageAbstract::~SieveWidgetPageAbstract()
-{
-}
+SieveWidgetPageAbstract::~SieveWidgetPageAbstract() = default;
 
 void SieveWidgetPageAbstract::setPageType(PageType type)
 {
