@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveeditortabwidget.h"
 #include "webengine/sieveeditorhelphtmlwidget.h"
@@ -36,9 +23,7 @@ SieveEditorTabWidget::SieveEditorTabWidget(QWidget *parent)
     connect(this, &SieveEditorTabWidget::customContextMenuRequested, this, &SieveEditorTabWidget::slotTabContextMenuRequest);
 }
 
-SieveEditorTabWidget::~SieveEditorTabWidget()
-{
-}
+SieveEditorTabWidget::~SieveEditorTabWidget() = default;
 
 void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
 {
@@ -53,10 +38,10 @@ void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
     }
     QMenu menu(this);
 
-    const int countTab = (count() > 1);
+    const bool hasMoreThanTwoTab = (count() > 1);
 
     QAction *closeTab = nullptr;
-    if ((indexBar != 0) && countTab) {
+    if ((indexBar != 0) && hasMoreThanTwoTab) {
         closeTab = menu.addAction(i18nc("@action:inmenu", "Close Tab"));
         closeTab->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
     }
@@ -68,16 +53,16 @@ void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
     }
 
     QAction *allTab = nullptr;
-    if (countTab) {
+    if (hasMoreThanTwoTab) {
         allTab = menu.addAction(i18nc("@action:inmenu", "Close All Tabs"));
-        allTab->setEnabled(countTab);
+        allTab->setEnabled(hasMoreThanTwoTab);
         allTab->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
     }
 
     QAction *action = menu.exec(mapToGlobal(pos));
 
     if (action) {
-        if (action == allOther) {   // Close all other tabs
+        if (action == allOther) { // Close all other tabs
             slotCloseAllTabExcept(indexBar);
         } else if (action == closeTab) {
             slotCloseRequest(indexBar);
@@ -96,7 +81,7 @@ void SieveEditorTabWidget::slotCloseRequest(int index)
 
 void SieveEditorTabWidget::closeAllTabExcept(int index)
 {
-    //Don't close first tab
+    // Don't close first tab
     for (int i = count() - 1; i > 0; --i) {
         if (i == index) {
             continue;
@@ -117,7 +102,7 @@ void SieveEditorTabWidget::slotCloseAllTab()
 
 void SieveEditorTabWidget::slotTabCloseRequested(int index)
 {
-    //Don't remove first tab.
+    // Don't remove first tab.
     if (index > 0) {
         removeTab(index);
     }
@@ -125,38 +110,38 @@ void SieveEditorTabWidget::slotTabCloseRequested(int index)
 
 bool SieveEditorTabWidget::currentPageIsHtmlPage() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     return page ? true : false;
 }
 
 QUrl SieveEditorTabWidget::currentHelpUrl() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->currentUrl();
     }
-    return QUrl();
+    return {};
 }
 
 QString SieveEditorTabWidget::currentHelpTitle() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->title();
     }
-    return QString();
+    return {};
 }
 
 void SieveEditorTabWidget::slotAddHelpPage(const QUrl &url)
 {
     for (int i = 0; i < count(); ++i) {
-        SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
+        auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
         if (page && page->currentUrl() == url) {
             setCurrentIndex(i);
             return;
         }
     }
-    SieveEditorHelpHtmlWidget *htmlPage = new SieveEditorHelpHtmlWidget;
+    auto htmlPage = new SieveEditorHelpHtmlWidget;
     connect(htmlPage, &SieveEditorHelpHtmlWidget::titleChanged, this, &SieveEditorTabWidget::slotTitleChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged, this, &SieveEditorTabWidget::slotProgressIndicatorPixmapChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::loadFinished, this, &SieveEditorTabWidget::slotLoadFinished);
