@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -21,7 +21,9 @@
 #include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/SlideContainer>
 #include <KPIMTextEdit/TextGotoLineWidget>
-#include <KPIMTextEdit/TextToSpeechWidget>
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechContainerWidget>
+#endif
 
 #include <ksieve/error.h>
 #include <ksieve/parser.h>
@@ -31,10 +33,11 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
+#include <KWindowStateSaver>
 
-#include <PimCommon/KPimPrintPreviewDialog>
 #include <QPointer>
 #include <QPrintDialog>
+#include <QPrintPreviewDialog>
 #include <QPrinter>
 #include <QPushButton>
 #include <QShortcut>
@@ -52,7 +55,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     auto lay = new QVBoxLayout(this);
     lay->setContentsMargins({});
 
-    mMainSplitter = new QSplitter;
+    mMainSplitter = new QSplitter(this);
     mMainSplitter->setOrientation(Qt::Vertical);
     lay->addWidget(mMainSplitter);
 
@@ -61,34 +64,38 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     //
     mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
-    auto textEditWidget = new QWidget;
+    auto textEditWidget = new QWidget(this);
     auto textEditLayout = new QVBoxLayout;
     textEditLayout->setContentsMargins({});
 
-    mEditorWidget = new QWidget;
+    mEditorWidget = new QWidget(this);
     auto editorWidgetLayout = new QVBoxLayout;
     editorWidgetLayout->setContentsMargins({});
     mEditorWidget->setLayout(editorWidgetLayout);
 
-    mTabWidget = new SieveEditorTabWidget;
+    mTabWidget = new SieveEditorTabWidget(this);
     connect(mTabWidget, &SieveEditorTabWidget::currentChanged, this, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged);
     connect(mTabWidget, &SieveEditorTabWidget::copyAvailable, this, &SieveEditorTextModeWidget::copyAvailable);
-    mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    mTextToSpeechWidget = new TextEditTextToSpeech::TextToSpeechContainerWidget(this);
     editorWidgetLayout->addWidget(mTextToSpeechWidget);
+#endif
 
-    mTextEdit = new SieveTextEdit;
+    mTextEdit = new SieveTextEdit(this);
     editorWidgetLayout->addWidget(mTextEdit);
     connect(mTextEdit, &SieveTextEdit::textChanged, this, &SieveEditorTextModeWidget::valueChanged);
     mTabWidget->addTab(mEditorWidget, i18n("Editor"));
     mTabWidget->tabBar()->hide();
     textEditLayout->addWidget(mTabWidget);
     connect(mTextEdit, &SieveTextEdit::openHelp, mTabWidget, &SieveEditorTabWidget::slotAddHelpPage);
-    connect(mTextEdit, &SieveTextEdit::say, mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    connect(mTextEdit, &SieveTextEdit::say, mTextToSpeechWidget, &TextEditTextToSpeech::TextToSpeechContainerWidget::say);
+#endif
     connect(mTextEdit, &SieveTextEdit::editRule, this, &SieveEditorTextModeWidget::slotEditRule);
     connect(mTextEdit, &SieveTextEdit::insertRule, this, &SieveEditorTextModeWidget::slotInsertRule);
 
     mGotoLineSliderContainer = new KPIMTextEdit::SlideContainer(this);
-    mGoToLine = new KPIMTextEdit::TextGoToLineWidget;
+    mGoToLine = new KPIMTextEdit::TextGoToLineWidget(this);
     mGoToLine->hide();
     mGotoLineSliderContainer->setContent(mGoToLine);
     editorWidgetLayout->addWidget(mGotoLineSliderContainer);
@@ -105,7 +112,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mSliderContainer->setContent(mFindBar);
     editorWidgetLayout->addWidget(mSliderContainer);
 
-    mSieveEditorWarning = new SieveEditorWarning;
+    mSieveEditorWarning = new SieveEditorWarning(this);
     editorWidgetLayout->addWidget(mSieveEditorWarning);
 
     mSieveParsingWarning = new SieveEditorParsingMissingFeatureWarning(SieveEditorParsingMissingFeatureWarning::TextEditor);
@@ -125,7 +132,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     connect(mTextEdit, &SieveTextEdit::findText, this, &SieveEditorTextModeWidget::slotFind);
     connect(mTextEdit, &SieveTextEdit::replaceText, this, &SieveEditorTextModeWidget::slotReplace);
 
-    mDebugTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
+    mDebugTextEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     mDebugTextEdit->editor()->setSearchSupport(false);
     mDebugTextEdit->editor()->setReadOnly(true);
     mDebugTextEdit->editor()->setPlaceholderText(i18n("Show result from \"check syntax\""));
@@ -437,7 +444,8 @@ void SieveEditorTextModeWidget::printPreview()
     if (w == mEditorWidget) {
         bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
         mTextEdit->setCheckSpellingEnabled(false);
-        QPointer<PimCommon::KPimPrintPreviewDialog> previewdlg = new PimCommon::KPimPrintPreviewDialog(this);
+        QPointer<QPrintPreviewDialog> previewdlg = new QPrintPreviewDialog(this);
+        new KWindowStateSaver(previewdlg.data(), "SieveEditorPrintPreviewDialog");
         connect(previewdlg.data(), &QPrintPreviewDialog::paintRequested, this, [this](QPrinter *printer) {
             mTextEdit->print(printer);
         });
@@ -447,9 +455,9 @@ void SieveEditorTextModeWidget::printPreview()
     }
 }
 
-void SieveEditorTextModeWidget::wordWrap(bool state)
+void SieveEditorTextModeWidget::setWordWrap(bool state)
 {
-    mTextEdit->wordWrap(state);
+    mTextEdit->setWordWrap(state);
 }
 
 void SieveEditorTextModeWidget::zoomReset()
