@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -31,9 +31,7 @@ using namespace KSieveUi;
 class KSieveUi::SieveTextEditPrivate
 {
 public:
-    SieveTextEditPrivate()
-    {
-    }
+    SieveTextEditPrivate() = default;
 
     SieveLineNumberArea *m_sieveLineNumberArea = nullptr;
     KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
@@ -429,7 +427,7 @@ bool SieveTextEdit::isWordWrap() const
     return wordWrapMode() == QTextOption::WordWrap;
 }
 
-void SieveTextEdit::wordWrap(bool state)
+void SieveTextEdit::setWordWrap(bool state)
 {
     setWordWrapMode(state ? QTextOption::WordWrap : QTextOption::NoWrap);
 }
