@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -40,9 +40,7 @@ SieveEditorTestWidget::SieveEditorTestWidget(QWidget *parent)
     connect(this, &SieveEditorTestWidget::valueChanged, this, &SieveEditorTestWidget::slotValueChanged);
 }
 
-SieveEditorTestWidget::~SieveEditorTestWidget()
-{
-}
+SieveEditorTestWidget::~SieveEditorTestWidget() = default;
 
 void SieveEditorTestWidget::slotValueChanged(bool changed)
 {
