@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,6 +18,4 @@ SieveEditorWarning::SieveEditorWarning(QWidget *parent)
     setWordWrap(true);
 }
 
-SieveEditorWarning::~SieveEditorWarning()
-{
-}
+SieveEditorWarning::~SieveEditorWarning() = default;
