@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -22,9 +22,9 @@ public:
     ~FindBarWebEngineView() override;
 
 private:
-    void clearSelections() override;
-    void searchText(bool backward, bool isAutoSearch) override;
-    void updateSensitivity(bool sensitivity) override;
+    KSIEVEUI_NO_EXPORT void clearSelections() override;
+    KSIEVEUI_NO_EXPORT void searchText(bool backward, bool isAutoSearch) override;
+    KSIEVEUI_NO_EXPORT void updateSensitivity(bool sensitivity) override;
 
 private:
     std::unique_ptr<FindBarWebEngineViewPrivate> const d;
