@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveeditorhelphtmlwidget.h"
 #include "sieveeditorloadprogressindicator.h"
@@ -28,7 +15,8 @@
 #include "findbar/findbarwebengineview.h"
 
 using namespace KSieveUi;
-namespace {
+namespace
+{
 qreal zoomBy()
 {
     return 20;
@@ -36,10 +24,9 @@ qreal zoomBy()
 }
 SieveEditorHelpHtmlWidget::SieveEditorHelpHtmlWidget(QWidget *parent)
     : QWidget(parent)
-    , mZoomFactor(100)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
     mProgressIndicator = new SieveEditorLoadProgressIndicator(this);
     mProgressIndicator->setObjectName(QStringLiteral("progressindicator"));
     connect(mProgressIndicator, &SieveEditorLoadProgressIndicator::pixmapChanged, this, &SieveEditorHelpHtmlWidget::slotPixmapChanged);
@@ -62,9 +49,7 @@ SieveEditorHelpHtmlWidget::SieveEditorHelpHtmlWidget(QWidget *parent)
     mSliderContainer->setContent(mFindBar);
 }
 
-SieveEditorHelpHtmlWidget::~SieveEditorHelpHtmlWidget()
-{
-}
+SieveEditorHelpHtmlWidget::~SieveEditorHelpHtmlWidget() = default;
 
 QString SieveEditorHelpHtmlWidget::title() const
 {
