@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ SieveEditorLoadProgressIndicator::SieveEditorLoadProgressIndicator(QObject *pare
     connect(mProgressTimer, &QTimer::timeout, this, &SieveEditorLoadProgressIndicator::slotTimerDone);
 }
 
-SieveEditorLoadProgressIndicator::~SieveEditorLoadProgressIndicator()
-{
-}
+SieveEditorLoadProgressIndicator::~SieveEditorLoadProgressIndicator() = default;
 
 void SieveEditorLoadProgressIndicator::startAnimation()
 {
