@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDEBUGGERRESULTEDITOR_H
-#define SIEVESCRIPTDEBUGGERRESULTEDITOR_H
+#pragma once
 
 #include <KPIMTextEdit/PlainTextEditor>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptDebuggerResultEditor : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -25,4 +25,3 @@ private:
     void slotSaveAs();
 };
 }
-#endif // SIEVESCRIPTDEBUGGERRESULTEDITOR_H
