@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ SieveScriptDebuggerTextEdit::SieveScriptDebuggerTextEdit(QWidget *parent)
     setWordWrapMode(QTextOption::WordWrap);
 }
 
-SieveScriptDebuggerTextEdit::~SieveScriptDebuggerTextEdit()
-{
-}
+SieveScriptDebuggerTextEdit::~SieveScriptDebuggerTextEdit() = default;
 
 void SieveScriptDebuggerTextEdit::addExtraMenuEntry(QMenu *menu, QPoint pos)
 {
