@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -41,7 +41,7 @@ Q_SIGNALS:
     void sieveTestNotFound();
 
 private:
-    void checkSieveTestApplication();
+    KSIEVEUI_NO_EXPORT void checkSieveTestApplication();
     QStackedWidget *mStackedWidget = nullptr;
     SieveScriptDebuggerFrontEndWidget *mSieveScriptFrontEnd = nullptr;
     QLabel *mSieveNoExistingFrontEnd = nullptr;
