@@ -1,34 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievetemplatewidget.h"
-#include "sievetemplateeditdialog.h"
 #include "sievedefaulttemplate.h"
+#include "sievetemplateeditdialog.h"
 #include <PimCommon/TemplateManager>
-#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 
 #include <KLocalizedString>
 
-#include <QPointer>
 #include <QLabel>
-#include <QVBoxLayout>
 #include <QMimeData>
+#include <QPointer>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 SieveTemplateListWidget::SieveTemplateListWidget(const QString &configName, QWidget *parent)
@@ -44,12 +30,16 @@ void SieveTemplateListWidget::setSieveCapabilities(const QStringList &capabiliti
     mCapabilities = capabilities;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> items) const
+#else
+QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> &items) const
+#endif
 {
     if (items.isEmpty()) {
         return nullptr;
     }
-    QMimeData *mimeData = new QMimeData();
+    auto mimeData = new QMimeData();
     QListWidgetItem *item = items.first();
     QString templateStr = item->data(TemplateListWidget::Text).toString();
     if (!mCapabilities.contains(QLatin1String("imap4flags")) && templateStr.contains(QLatin1String("imap4flags"))) {
@@ -59,9 +49,7 @@ QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> item
     return mimeData;
 }
 
-SieveTemplateListWidget::~SieveTemplateListWidget()
-{
-}
+SieveTemplateListWidget::~SieveTemplateListWidget() = default;
 
 QVector<PimCommon::defaultTemplate> SieveTemplateListWidget::defaultTemplates()
 {
@@ -103,9 +91,9 @@ bool SieveTemplateListWidget::modifyTemplate(QString &templateName, QString &tem
 SieveTemplateWidget::SieveTemplateWidget(const QString &title, QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
-    QLabel *lab = new QLabel(title, this);
+    auto lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
+    auto lab = new QLabel(title, this);
     lay->addWidget(lab);
     mListTemplate = new SieveTemplateListWidget(QStringLiteral("sievetemplaterc"), this);
     mListTemplate->setWhatsThis(i18n("You can drag and drop element on editor to import template"));
@@ -113,9 +101,7 @@ SieveTemplateWidget::SieveTemplateWidget(const QString &title, QWidget *parent)
     lay->addWidget(mListTemplate);
 }
 
-SieveTemplateWidget::~SieveTemplateWidget()
-{
-}
+SieveTemplateWidget::~SieveTemplateWidget() = default;
 
 void SieveTemplateWidget::setSieveCapabilities(const QStringList &capabilities)
 {
