@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -30,11 +30,11 @@ Q_SIGNALS:
     void searchServerWithVacationSupportFinished(const QMap<QString, KSieveUi::Util::AccountInfo> &info);
 
 private:
-    void slotFindAccountInfoFinished(const KSieveUi::Util::AccountInfo &info);
-    void sendAccountList();
-    void searchNextInfo();
-    void slotSearchSieveScript(const QString &name, const QString &identifier);
-    void searchNextServerSieve();
+    KSIEVEUI_NO_EXPORT void slotFindAccountInfoFinished(const KSieveUi::Util::AccountInfo &info);
+    KSIEVEUI_NO_EXPORT void sendAccountList();
+    KSIEVEUI_NO_EXPORT void searchNextInfo();
+    KSIEVEUI_NO_EXPORT void slotSearchSieveScript(const QString &name, const QString &identifier);
+    KSIEVEUI_NO_EXPORT void searchNextServerSieve();
 
     QMap<QString, QString>::const_iterator mSieveServerMapIterator;
     // name, identifier
@@ -45,4 +45,3 @@ private:
     SieveImapPasswordProvider *mPasswordProvider = nullptr;
 };
 }
-
