@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -64,9 +64,7 @@ VacationPageWidget::VacationPageWidget(QWidget *parent)
     mStackWidget->setCurrentIndex(Script);
 }
 
-VacationPageWidget::~VacationPageWidget()
-{
-}
+VacationPageWidget::~VacationPageWidget() = default;
 
 bool VacationPageWidget::wasChanged() const
 {
